function bmscex34
% In this exercise we simulate Brownian motion using the Wiener-Levy
% Representation (see Corollary I.(5.16) in the lecture notes)

% upper bound on n
nmax=12;          
% number of iid normal variables
N=sum(2.^[1:nmax]);
% number of sample paths
M=10;           
% final time
T=1;             
% number of grid points
gridpoi=2000;     
% time grid
grid=0:T/gridpoi:T;    
% iid std normal random variables
Y=randn(N,M);          
% output matrix (N,M)=(N*1)*(1*M) matrix, initialize for n=0: Y_0*phi_0(t)
out=grid'*randn(1,M);

% use the definition of W^N
for n=1:nmax
    for k=1:(2^n)
        % formula I.(5.8)
    out=out+(schauderba(n,k,grid))'*Y(2^(n-1)+k,:);     
    end
end
plot(grid,out)
title('BM with Wiener-Levy representation');
xlabel('time');
ylabel('value');
end


function[value]=schauderba(n,k,t)
% the function implements the schauderbasis function see definition I (5.7)
ind1=t> (2*k-2)*2^(-(n+1));
ind2=t<= (2*k-1)*2^(-(n+1));

ind3=1-ind2;
ind4=t<=2*k*2^(-(n+1));

% Definition of the Schauder basis function definition I (5.7)
value=(ind1.*ind2).*2^(n/2).*(t-(k-1)*2^(-n))...
    -(ind3.*ind4).*2^(n/2).*(t-k*2^(-n));
end